diff dbdefs.inc.php @ 1034:8fecb417e6a9

Reintroduce per-entry preview_type.
author Matti Hamalainen <ccr@tnsp.org>
date Fri, 20 Nov 2015 07:28:53 +0200
parents e6e6be0218f8
children f188caaedf0f
line wrap: on
line diff
--- a/dbdefs.inc.php	Fri Nov 20 07:20:39 2015 +0200
+++ b/dbdefs.inc.php	Fri Nov 20 07:28:53 2015 +0200
@@ -262,9 +262,8 @@
     array("visible"      , "INT", "DEFAULT 0"),
     array("voting"       , "INT", "DEFAULT 0"),
     
     // Default preview type (see PREV_* in msite.inc.php)
     // Global for the compo (entry-specific overrides if it is != PREV_NONE)
     // Preview filename/path is determined internally
     array("preview_type" , "INT", "DEFAULT 0"),
 
     array("show_authors" , "INT", "DEFAULT 0"),
@@ -287,6 +286,7 @@
     array("evalue"       , "INT", "DEFAULT 0"),
     array("file_id"      , "INT", "DEFAULT 0"), // uploaded file id from "files" table
     array("preview_id"   , "INT", "DEFAULT 0"), // uploaded preview file id from "files" table
+    array("preview_type" , "INT", "DEFAULT 0"), // see EFILE_*, overrides compo's general type if != 0
     array("utime"        , "INT", "DEFAULT 0"),
     array("owner_id"     , "INT", "DEFAULT 0"), // 0 = admin, otherwise votekey id
   ),
@@ -262,9 +262,8 @@
     array("voting"       , "INT", "DEFAULT 0"),
     
-    // Default preview type (see PREV_* in msite.inc.php)
-    // Global for the compo (entry-specific overrides if it is != PREV_NONE)
-    // Preview filename/path is determined internally
+    // Default preview type (see EFILE_* in msite.inc.php) for this compo.
+    // Global for the compo (entry-specific overrides if it is != EFILE_NONE)
     array("preview_type" , "INT", "DEFAULT 0"),
 